import { defineStore } from "pinia";
import { store } from "/@/store";
import { userType, resType } from "./types";
import { router } from "/@/router";
import { routerArrays } from "/@/layout/types";
import { storageSession } from "@pureadmin/utils";
import { getLogin, getAsyncRoutes, refreshToken } from "/@/api/user";
import {
  getToken,
  setToken,
  removeToken,
  getAction,
  setAction,
  removeAction
} from "/@/utils/auth";

import { useMultiTagsStoreHook } from "/@/store/modules/multiTags";

export const useUserStore = defineStore({
  id: "pure-user",
  state: (): userType => ({
    token: getToken(),
    name: "admin",
    // 前端生成的验证码（按实际需求替换）
    verifyCode: "",
    // 登录显示组件判断 0：登录 1：手机登录 2：二维码登录 3：注册 4：忘记密码，默认0：登录
    currentPage: 0,
    menuActions: getAction()
  }),
  getters: {
    getMenuActions() {
      if (this.menuActions && this.menuActions.length > 0) {
        return JSON.parse(this.menuActions);
      } else {
        return [];
      }
    }
  },
  actions: {
    SET_TOKEN(token) {
      this.token = token;
    },
    SET_NAME(name) {
      this.name = name;
    },
    SET_VERIFYCODE(verifyCode) {
      this.verifyCode = verifyCode;
    },
    SET_CURRENTPAGE(value) {
      this.currentPage = value;
    },
    SET_ACTIONS(value) {
      this.actions = value;
    },
    // 登入
    async loginByUsername(form) {
      return new Promise((resolve, reject) => {
        getLogin(form)
          .then((res: resType) => {
            const { code, data } = res;
            if (code === 0) {
              const { token } = data;
              setToken(token);
              resolve(res);
            } else {
              resolve(res);
            }
          })
          .catch(error => {
            reject(error);
          });
      });
    },

    // 获取当前账号菜单数据
    async postMenuList(form) {
      return new Promise((resolve, reject) => {
        getAsyncRoutes(form)
          .then((res: resType) => {
            const { code, data } = res;
            if (code === 0) {
              const actionList: Array<any> = [];
              data.forEach(e => {
                e.child?.forEach(s => {
                  const item = {
                    menu_route: s.menu_route,
                    action: s.action
                  };
                  actionList.push(item);
                });
              });
              setAction(JSON.stringify(actionList));
              resolve(res);
            } else {
              resolve(res);
            }
          })
          .catch(error => {
            reject(error);
          });
      });
    },
    // 登出 清空缓存
    logOut() {
      this.token = "";
      this.name = "";
      removeToken();
      removeAction();
      storageSession.clear();
      useMultiTagsStoreHook().handleTags("equal", routerArrays);
      router.push("/login");
    },
    // 刷新token
    async refreshToken(data) {
      return refreshToken(data).then(data => {
        if (data) {
          setToken(data);
          return data;
        }
      });
    }
  }
});

export function useUserStoreHook() {
  return useUserStore(store);
}
