import { ElForm, FormRules } from "element-plus";
import { reactive, ref, watchEffect } from "vue";

export function useReviewProcess({
  callback,
  failStatus
}: {
  callback: () => void;
  failStatus: string;
}) {
  const formRef = ref<InstanceType<typeof ElForm>>(null);

  const formData = reactive({
    status: "",
    remark: ""
  });

  const rules = reactive<FormRules>({
    status: [{ required: true, trigger: "change", message: "请选择审核状态" }],
    remark: [{ required: false, trigger: "change", message: "请选择审核状态" }]
  });

  function handleAudit() {
    formRef.value.validate(isValid => {
      if (isValid) callback();
    });
  }

  //不通过时备注必填
  watchEffect(() => {
    const { status } = formData;
    rules.remark[0].required = status === failStatus;
  });

  return {
    rules,
    formRef,
    formData,
    handleAudit
  };
}
